---
name: Feature request
about: Suggest an idea for this project
title: ''
labels: enhancement
assignees: ''

---

**Category**
Please select:
- [ ] shrike.pipeline
- [ ] shrike.build
- [ ] shrike.compliant_logging

Please also add corresponding labels.

**Is your feature request related to a problem? Please describe.**
A clear and concise description of what the problem is. Ex. I'm always frustrated when [...]

**Describe the solution you'd like**
A clear and concise description of what you want to happen.

**Describe alternatives you've considered**
A clear and concise description of any alternative solutions or features you've considered.

**Estimate the Impact**
1. How many people/teams would benefit from that new feature?

2. Are you able to quantify the impact of (not) having this feature? E.g. "this would save me 2 hours a week" or "not having this functionality makes us use 15% more CPU time".

**Additional context**
Add any other context or screenshots about the feature request here.

